@@ -6,7 +6,7 @@ class Params:
     def __init__(self, chain_name='polygon.mainnet'):
         if chain_name == 'polygon.mainnet' or chain_name == 'main':
             self.MCS_API = MCS_POLYGON_MAIN_API
-        elif chain_name == 'polygon.mumbai':
+        elif chain_name == 'mumbai':
             self.MCS_API = MCS_POLYGON_MUMBAI_API
         elif chain_name == 'bsc':
             self.MCS_API = MCS_BSC_API
